Class: Paru::PandocFilter::Plain

Inherits:
Block
  • Object
show all
Includes:
InnerMarkdown
Defined in:
lib/paru/filter/plain.rb

Overview

A Plain node is a basic Block level node with Inline child nodes. Not to be confused with Para, which represents a paragraph. A Plain is a more general type of block level node.

Instance Attribute Summary

Attributes inherited from Node

#children, #parent

Instance Method Summary collapse

Methods included from InnerMarkdown

#inner_markdown, #inner_markdown=

Methods inherited from Block

#is_block?

Methods inherited from Node

#ast_contents, #ast_type, #can_act_as_both_block_and_inline?, #each, from_markdown, #get_replacement, #has_been_replaced?, #has_block?, #has_children?, #has_class?, #has_parent?, #has_string?, #is_block?, #is_inline?, #is_leaf?, #is_node?, #is_root?, #markdown, #markdown=, #toMetadata, #to_ast, #to_s, #type

Methods included from ASTManipulation

#append, #delete, #each_depth_first, #find_index, #get, #insert, #prepend, #remove_at, #replace, #replace_at

Constructor Details

#initialize(contents) ⇒ Plain

Create a new Plain node based on contents

Parameters:

  • contents (Array)


35
36
37
# File 'lib/paru/filter/plain.rb', line 35

def initialize(contents)
  super(contents, true)
end

Instance Method Details

#has_inline?Boolean

Has a Plain node inline contents?

Returns:

  • (Boolean)

    true



42
43
44
# File 'lib/paru/filter/plain.rb', line 42

def has_inline?
  true
end