Class: Paru::PandocFilter::Span

Inherits:
Inline show all
Defined in:
lib/paru/filter/span.rb

Overview

A Span node is a general Inline level node with attributes and contens

Instance Attribute Summary collapse

Attributes inherited from Node

#children, #parent

Instance Method Summary collapse

Methods inherited from Inline

#has_inline?, #is_inline?

Methods included from InnerMarkdown

#inner_markdown, #inner_markdown=

Methods inherited from Node

#ast_type, #can_act_as_both_block_and_inline?, #each, from_markdown, #get_replacement, #has_been_replaced?, #has_block?, #has_children?, #has_class?, #has_inline?, #has_parent?, #has_string?, #is_block?, #is_inline?, #is_leaf?, #is_node?, #is_root?, #markdown, #markdown=, #toMetadata, #to_ast, #to_s, #type

Methods included from ASTManipulation

#append, #delete, #each_depth_first, #find_index, #get, #insert, #prepend, #remove_at, #replace, #replace_at

Constructor Details

#initialize(contents) ⇒ Span

Create a new Span node based on the contents

Parameters:

  • contents (Array)


37
38
39
40
# File 'lib/paru/filter/span.rb', line 37

def initialize(contents)
  @attr = Attr.new contents[0]
  super(contents[1])
end

Instance Attribute Details

#attrAttr

Returns:



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/paru/filter/span.rb', line 31

class Span < Inline
  attr_accessor :attr

  # Create a new Span node based on the contents
  #
  # @param contents [Array]
  def initialize(contents)
    @attr = Attr.new contents[0]
    super(contents[1])
  end

  # The AST contents
  #
  # @return [Array]
  def ast_contents
    [
      @attr.to_ast,
      super
    ]
  end
end

Instance Method Details

#ast_contentsArray

The AST contents

Returns:

  • (Array)


45
46
47
48
49
50
# File 'lib/paru/filter/span.rb', line 45

def ast_contents
  [
    @attr.to_ast,
    super
  ]
end