Class: Paru::PandocFilter::Figure
- Includes:
- InnerMarkdown
- Defined in:
- lib/paru/filter/figure.rb
Overview
A Figure node consisting of an attribute object, a caption, and a list of Block nodes.
Instance Attribute Summary collapse
- #attr ⇒ Attr
-
#caption ⇒ Object
Caption.
Attributes inherited from Node
Instance Method Summary collapse
-
#ast_contents ⇒ Object
Create an AST representation of this Figure node.
-
#has_block? ⇒ Boolean
Has this Figure node Blocks as children?.
-
#initialize(contents) ⇒ Figure
constructor
Create a new Figure node based on the contents.
Methods included from InnerMarkdown
#inner_markdown, #inner_markdown=
Methods inherited from Block
Methods inherited from Node
#ast_type, #can_act_as_both_block_and_inline?, #each, from_markdown, #get_replacement, #has_been_replaced?, #has_children?, #has_class?, #has_inline?, #has_parent?, #has_string?, #is_block?, #is_inline?, #is_leaf?, #is_node?, #is_root?, #markdown, #markdown=, #toMetadata, #to_ast, #to_s, #type
Methods included from ASTManipulation
#append, #delete, #each_depth_first, #find_index, #get, #insert, #prepend, #remove_at, #replace, #replace_at
Constructor Details
Instance Attribute Details
#caption ⇒ Object
Returns Caption.
39 |
# File 'lib/paru/filter/figure.rb', line 39 attr_accessor :attr, :caption |
Instance Method Details
#ast_contents ⇒ Object
Create an AST representation of this Figure node.
51 52 53 54 55 56 57 |
# File 'lib/paru/filter/figure.rb', line 51 def ast_contents [ @attr.to_ast, @caption.to_ast, super ] end |
#has_block? ⇒ Boolean
Has this Figure node Blocks as children?
62 63 64 |
# File 'lib/paru/filter/figure.rb', line 62 def has_block? true end |