Class: Paru::PandocFilter::Image
- Defined in:
- lib/paru/filter/image.rb
Overview
An Image has an attribute object, a caption, and a target
Instance Attribute Summary
Attributes inherited from Link
Attributes inherited from Node
Instance Method Summary collapse
-
#can_act_as_both_block_and_inline? ⇒ Boolean
Although Image is defined to be inline, probably because in HTML it can be an inline element, often it acts like a block element.
Methods inherited from Link
Methods inherited from Inline
#has_inline?, #initialize, #is_inline?
Methods included from InnerMarkdown
#inner_markdown, #inner_markdown=
Methods inherited from Node
#ast_contents, #ast_type, #each, from_markdown, #get_replacement, #has_been_replaced?, #has_block?, #has_children?, #has_class?, #has_inline?, #has_parent?, #has_string?, #initialize, #is_block?, #is_inline?, #is_leaf?, #is_node?, #is_root?, #markdown, #markdown=, #toMetadata, #to_ast, #to_s, #type
Methods included from ASTManipulation
#append, #delete, #each_depth_first, #find_index, #get, #insert, #prepend, #remove_at, #replace, #replace_at
Constructor Details
This class inherits a constructor from Paru::PandocFilter::Link
Instance Method Details
#can_act_as_both_block_and_inline? ⇒ Boolean
Although Image is defined to be inline, probably because in HTML it can be an inline element, often it acts like a block element.
30 31 32 |
# File 'lib/paru/filter/image.rb', line 30 def can_act_as_both_block_and_inline? true end |